@@ -270,8 +270,10 @@ gboolean load_groups(GtkWidget* main, gchar *session) {
 
 		combo = (GtkComboBox*) lookup_widget(main, "combo_session");
 //		while (i = gtk_combo_box_get_active(combo) != -1) gtk_combo_box_remove_text(combo, i);
-		for (i = 0; i < session_number; i++) gtk_combo_box_remove_text(combo, 0);
-
+		for (i = 0; i < session_number; i++) {
+			// printf("%i\n", i);
+			gtk_combo_box_remove_text(combo, 0);
+		}
 		settings_file = g_key_file_new();
 		g_key_file_load_from_file(settings_file, settings_file_path, 	G_KEY_FILE_NONE, &error_handler);
 		groups = g_key_file_get_groups(settings_file, &session_number);
@@ -315,7 +317,7 @@ gboolean load_groups(GtkWidget* main, gchar *session) {
 		if (session_last == -1) return FALSE;
 	}
 /*
-	 else {
+	else {
 		g_printf (_("(ERROR) Can't open config file! Maybe this is the first run?\n"));
 //		return FALSE;
 	}
@@ -892,6 +894,7 @@ void on_session_add_clicked(GtkButton *button, gpointer user_data) {
 
 		save_settings((GtkWidget*) button, newses, NULL);
 		session_number++;
+		session_last = -1;		// added because of save session bug, copied from external patch
 		load_groups((GtkWidget*) button, newses);
 	}
 	gtk_widget_destroy(add);
